pub enum MobEffectParticle {
EffectColor {
particle_type: ParticleTypeRef,
regular_alpha: u8,
ambient_alpha: u8,
},
Simple(ParticleTypeRef),
FixedColor {
particle_type: ParticleTypeRef,
color: ArgbColor,
},
}Expand description
The Vanilla particle factory associated with a mob effect.
Variants
EffectColor
Builds a color payload from the effect color and instance ambience.
Simple(ParticleTypeRef)
Uses a simple particle without a payload.
FixedColor
Uses one fixed ARGB color payload for every instance.
Implementations
Sourceimpl MobEffectParticle
impl MobEffectParticle
pub fn create(self, effect_color: RgbColor, ambient: bool) -> ParticleData